Description: Az Pusztító viharok nyomában egy izgalmas dokumentumsorozat, amely szélsőséges időjárási jelenségeket mutat be olyan érzékletességgel, mintha mi magunk is résztvevői lennénk az eseményeknek. Sokkoló tornádó Iowában 2019 júliusában, elszabadult káosz Ottawában és Mississippiben, pusztító hurrikánok, valamint féktelen áradások Marylandben és Texasban. Végig követhetjük hogyan alakultak ki jelenkorunk katasztrofális időjárási eseményei, valamint megtudhatjuk azt is milyen hatással bírnak környezetünkre.

Összes

- Összes
- Személy
- Film
- Színdarab
- Tv műsor
- Esemény
- Csoport
- Helyszín
- TV csatorna
- Cikk

- Filmek estére
- Mozi
  - Moziműsor
  - Mozi premierek
- Színház
  - Színházműsor
  - Színházi bemutatók
- Hétvége
  - Hétvége
  - Gyerek hétvége
- Kritikák
- Trailerek
- Top 100 film
- Összes
  - Filmek estére
  - Moziműsor
  - Mozi premierek
  - Színházműsor
  - Színházi bemutatók
  - Hétvége
  - Gyerek hétvége
  - Kritikák
  - Trailerek
  - Top 100 film

- Filmek estére
- Moziműsor
- Mozi premierek
- Színházműsor
- Színházi bemutatók
- Hétvége
- Gyerek hétvége
- Kritikák
- Trailerek
- Top 100 film

Programkereső

- Ma
  - Ma
  - Holnap
  - A héten
  - Hétvégén
  - Bármikor
- Budapest
  - Országos
  - Ajka
  - Békéscsaba
  - Bölcske
  - Budaörs
  - Budapest
  - Bük (Bükfürdő)
  - Cegléd
  - Debrecen
  - Dunaújváros
  - Eger
  - Gödöllő
  - Gyenesdiás
  - Gyöngyös
  - Győr
  - Gyula
  - Hévíz
  - Hódmezővásárhely
  - Kaposvár
  - Kecskemét
  - Keszthely
  - Kisújszállás
  - Kisvárda
  - Martfű
  - Miskolc
  - Nagykanizsa
  - Nagykőrös
  - Nyíregyháza
  - Pécs
  - Salgótarján
  - Siófok
  - Sopron
  - Szeged
  - Székesfehérvár
  - Szekszárd
  - Szentendre
  - Szentes
  - Szigetszentmiklós
  - Szolnok
  - Szombathely
  - Tatabánya
  - Vác
  - Veszprém
  - Zalaegerszeg
- Mozi
  - TV
  - Mozi
  - Színház
  - Koncert
  - Fesztivál
  - Kiállítás
  - Könyv
  - Egyéb

# Pusztító viharok nyomában

Bakancslistához adom
Deadline To Disaster / Mayhem on Main Street
amerikai dokumentumfilm, I / 3. rész, 45 perc

## Még nincs szavazat!

Légy te az első!

Szólj hozzá!

Az Pusztító viharok nyomában egy izgalmas dokumentumsorozat, amely szélsőséges időjárási jelenségeket mutat be olyan érzékletességgel, mintha mi magunk is résztvevői lennénk az eseményeknek. Sokkoló tornádó Iowában 2019 júliusában, elszabadult káosz Ottawában és Mississippiben, pusztító hurrikánok, valamint féktelen áradások Marylandben és Texasban. Végig követhetjük hogyan alakultak ki jelenkorunk katasztrofális időjárási eseményei, valamint megtudhatjuk azt is milyen hatással bírnak környezetünkre.

## Évadok:

- 1

- Megosztom Facebookon

Szerkeszd te is a Port.hu-t!

#### Ha hiányosságot találsz, vagy valamihez van valamilyen érdekes hozzászólásod, írd meg nekünk!

Küldés

Figyelem: A beküldött észrevételeket a szerkesztőink értékelik, csak azok a javasolt változtatások valósulhatnak meg, amik jóváhagyást kapnak. Kérjük, forrásmegjelöléssel támaszd alá a leírtakat!

## Játszási időpontok

február 11. - szombat

- 13:00 Spektrum I / 3. rész

február 12. - vasárnap

- 13:00 Spektrum I / 3. rész

február 18. - szombat

- 13:00 Spektrum I / 1. rész

február 19. - vasárnap

- 13:00 Spektrum I / 6. rész

Spektrum
február 11. - szombat I / 6. rész

- 13:00

február 12. - vasárnap I / 6. rész

- 13:00

február 18. - szombat I / 6. rész

- 13:00

február 19. - vasárnap I / 6. rész

- 13:00

## Hozzászólások

Spoiler
Offtopik
Szerinted?

## Még nincs szavazat!

Légy te az első!

Szólj hozzá!

Vetítések:
23:05, csütörtök (február 09.)
Spektrum

# Mozi lista

- Budapest Kertmozi - Városmajor - Virág Benedek Ház
- Buda Bed Cinema - Ágymozi
- Autósmozi - Fővárosi Autópiac Budapest
- Westend Drive-In Cinema Autósmozi
- Cinema City Allee
- Cinema City Aréna
- Müpa Autósmozi
- Újpesti autósmozi
- Cinema City Campona
- Kino Cafe mozi

Kedvenc mozik szerkesztése »

# PORT.hu a Facebookon

##### Figyelmeztetés

Az értesítések jelenleg le vannak tiltva! Amennyiben szeretnél cikkajánlókat kapni, kérlek, hogy a böngésző Beállítások / Értesítések menüpontja alatt állítsd be az értesítések engedélyezését!

## Bejelentkezés

Jelentkezz be!

Belépek Facebookkal
VAGY
Hibás email cím vagy jelszó!
Elfelejtettem a jelszavam
Maradjak belépve
Regisztrálok»